@@ -6,6 +6,7 @@ import shutil
 import zipfile
 from overrides import overrides
 from packaging import version
+from tqdm import tqdm
 from typing import Any, Dict, List, Tuple
 
 from sacrerouge.commands import MetricSetupSubcommand
@@ -15,7 +16,7 @@ from sacrerouge.data import MetricsDict
 from sacrerouge.data.types import ReferenceType, SummaryType
 from sacrerouge.metrics import Metric, ReferenceBasedMetric
 
-MIN_QAEVAL_VERSION = '0.0.4'
+MIN_QAEVAL_VERSION = '0.0.8'
 QAEVAL_INSTALLED = False
 
 logger = logging.getLogger(__name__)
@@ -41,7 +42,7 @@ except ImportError:
 else:
     from qaeval import AnswerSelector, QuestionAnsweringModel, QuestionGenerationModel
     from qaeval.answer_selection import NP_CHUNKS_STRATEGY, AnswerOffsets
-    from qaeval.scoring.scorers import ExactMatchF1, LERC, MetaScorer
+    from qaeval.scoring.scorers import ExactMatchScorer, F1Scorer, IsAnsweredScorer, LERCScorer, MetaScorer
 
     QAEVAL_INSTALLED = True
 
@@ -57,16 +58,19 @@ else:
                      use_lerc: bool = False,
                      lerc_model_path: str = f'{DATA_ROOT}/metrics/qaeval/models/lerc/model.tar.gz',
                      lerc_pretrained_model_path: str = f'{DATA_ROOT}/metrics/qaeval/models/lerc/pretrained.tar.gz',
-                     lerc_batch_size: int = 8) -> None:
+                     lerc_batch_size: int = 8,
+                     verbose: bool = False) -> None:
             super().__init__()
             self.answer_selector = AnswerSelector(answer_selection_strategy)
-            self.question_generator = QuestionGenerationModel(generation_model_path, cuda_device=cuda_device, batch_size=generation_batch_size)
-            self.question_answerer = QuestionAnsweringModel(answering_model_dir, cuda_device=cuda_device, batch_size=answering_batch_size)
+            self.question_generator = QuestionGenerationModel(generation_model_path, cuda_device=cuda_device,
+                                                              batch_size=generation_batch_size, silent=not verbose)
+            self.question_answerer = QuestionAnsweringModel(answering_model_dir, cuda_device=cuda_device,
+                                                            batch_size=answering_batch_size, silent=not verbose)
+            self.verbose = verbose
 
-            scorers = [ExactMatchF1()]
-            self.use_lerc = use_lerc
-            if self.use_lerc:
-                scorers.append(LERC(lerc_model_path, lerc_pretrained_model_path, cuda_device, lerc_batch_size))
+            scorers = [IsAnsweredScorer(), ExactMatchScorer(), F1Scorer()]
+            if use_lerc:
+                scorers.append(LERCScorer(lerc_model_path, lerc_pretrained_model_path, cuda_device, lerc_batch_size))
             self.scorer = MetaScorer(scorers)
 
         def _flatten_summaries(self, summaries_list: List[List[SummaryType]]) -> List[List[str]]:
@@ -152,9 +156,9 @@ else:
                     end = answer.end - answer.sent_start
                     generation_inputs.append((sentence, start, end))
 
-            logging.info(f'Generating questions for {len(generation_inputs)} answers')
+            logger.info(f'Generating questions for {len(generation_inputs)} answers')
             question_list = self.question_generator.generate_all(generation_inputs)
-            logging.info('Finished generating questions')
+            logger.info('Finished generating questions')
 
             # Remap the questions to align with the answers
             index = 0
@@ -217,7 +221,7 @@ else:
                         mapping[(i, j, k)] = context_to_input_index[key]
 
             logger.info(f'Answering {len(qa_inputs)} distinct (question, context) pairs')
-            predictions = self.question_answerer.answer_all(qa_inputs)
+            predictions = self.question_answerer.answer_all(qa_inputs, return_offsets=True)
             logger.info('Finished answering questions')
 
             # Remap from the distinct answers back to the original QA lists
@@ -228,12 +232,14 @@ else:
                     predictions_lists[-1].append([])
                     for k, qa in enumerate(qa_pairs):
                         index = mapping[(i, j, k)]
-                        prediction, probability, null_probability = predictions[index]
+                        prediction, probability, null_probability, offsets = predictions[index]
                         predictions_lists[-1][-1].append({
                             'prediction_id': self._get_prediction_id(index),
                             'prediction': prediction,
                             'probability': probability,
-                            'null_probability': null_probability
+                            'null_probability': null_probability,
+                            'start': offsets[0],
+                            'end': offsets[1],
                         })
             return predictions_lists
 
@@ -241,10 +247,16 @@ else:
                                summaries: List[str],
                                qa_pairs_lists: List[List[List[Dict[str, Any]]]],
                                predictions_lists: List[List[List[Dict[str, Any]]]]) -> Tuple[List[MetricsDict], List[List[List[Dict[str, float]]]]]:
+            logger.info('Scoring predictions')
             metrics_list = []
             scores_list = []
 
-            for summary, qa_pairs_list, predictions_list in zip(summaries, qa_pairs_lists, predictions_lists):
+            generator = tqdm(
+                zip(summaries, qa_pairs_lists, predictions_lists),
+                total=len(summaries),
+                disable=not self.verbose
+            )
+            for summary, qa_pairs_list, predictions_list in generator:
                 # This is for 1 (summary, references) pair
                 input_questions_list = []
                 input_answers_list = []
@@ -265,11 +277,19 @@ else:
                         input_probabilities_list[-1].append(prediction['probability'])
                         input_null_probabilities_list[-1].append(prediction['null_probability'])
 
-                metrics, scores = self.scorer.score_multi_ref(summary, input_questions_list, input_answers_list, input_predictions_list, input_probabilities_list, input_null_probabilities_list)
+                metrics, scores = self.scorer.score_multi_ref(
+                    summary,
+                    input_questions_list,
+                    input_answers_list,
+                    input_predictions_list,
+                    input_probabilities_list,
+                    input_null_probabilities_list
+                )
                 metrics = MetricsDict({'qa-eval': metrics})
                 metrics_list.append(metrics)
                 scores_list.append(scores)
 
+            logger.info('Finished scoring predictions')
             return metrics_list, scores_list
 
         def _combine_outputs(self,
@@ -288,10 +308,8 @@ else:
                     combined[-1][1].append([])
                     for qa, prediction, score in zip(qa_pairs, predictions, scores):
                         prediction = dict(**prediction)
-                        prediction['em'] = score['em']
-                        prediction['f1'] = score['f1']
-                        if self.use_lerc:
-                            prediction['lerc'] = score['lerc']
+                        for key in self.scorer.keys():
+                            prediction[key] = score[key]
                         combined[-1][1][-1].append({'question': qa, 'prediction': prediction})
             return combined
 
@@ -303,10 +321,7 @@ else:
             index = 0
             for is_empty in is_empty_list:
                 if is_empty:
-                    if self.use_lerc:
-                        empty_metrics = MetricsDict({'qa-eval': {'em': 0.0, 'f1': 0.0, 'lerc': 0.0}})
-                    else:
-                        empty_metrics = MetricsDict({'qa-eval': {'em': 0.0, 'f1': 0.0}})
+                    empty_metrics = MetricsDict({'qa-eval': self.scorer.default_scores()})
                     if include_qa_list:
                         full_metrics_list.append((empty_metrics, []))
                     else:
